Models — django-sphinxdoc 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- django-sphinxdoc 1.2.0 documentation »
- API-Reference »

# Models

Models for django-sphinxdoc.

class `sphinxdoc.models.` `Document`(*args, **kwargs)

  Represents a JSON encoded Sphinx document. The attributes `title` and `body` dubicate the corresponding keys in `content` and are used for the Haystack search.

class `sphinxdoc.models.` `Project`(*args, **kwargs)

  Represents a Sphinx project. Each `Project` has a name, a slug and a path to the root directory of a Sphinx project (where Sphinx’ `conf.py`) is located).

### Navigation

- index
- modules |
- next |
- previous |
- django-sphinxdoc 1.2.0 documentation »
- API-Reference »